@@ -1,9 +1,3 @@
-#
-# $Id: dTemplate.pm 132 2006-10-21 15:52:44Z dlux $
-# 
-# $URL: http://svn.dlux.hu/public/dTemplate/trunk/dTemplate.pm $ 
-#
-
 package dTemplate;
 use strict;
 use DynaLoader;
@@ -13,7 +7,7 @@ use vars qw($VERSION @ISA %ENCODERS $ENCODERS %parse
 
 @ISA = qw(DynaLoader);
 
-$VERSION             = '2.4.2';
+$VERSION             = '2.3';
 $START_DELIMITER     = '\$';
 $END_DELIMITER       = '\$';
 $VAR_PATH_SEP        = '\.';
@@ -100,13 +94,9 @@ sub spf {
 
 *ENCODERS = *dTemplate::ENCODERS;
 
-sub FILENAME  { 0 };
-sub TEXT      { 1 };
-sub COMPILED  { 2 };
-sub PARSEHASH { 3 };
-
-# use this constant to determinene the last field for subclassing dTemplate
-sub LAST_FIELD { PARSEHASH };
+sub filename { 0 };
+sub text     { 1 };
+sub compiled { 2 };
 
 sub new { my ($class,$filename)=@_;
     return undef if ! -r $filename;
@@ -116,21 +106,21 @@ sub new { my ($class,$filename)=@_;
 
 sub new_raw { my $class=shift;
   my $txt=shift;
-  my $s=[undef, (ref($txt) ? $txt : \$txt)];
+  my $s=[undef, ref($txt) ? $txt : \$txt];
   bless ($s,$class);
 };
 
 sub style  { return undef };
 
 sub compile { my $s=shift;
-    return if $s->[COMPILED];
+    return if $s->[compiled];
     $s->load_file;
 
     # template parsing 
 
     my %varhash;
     my @comp=({});
-    ${ $s->[TEXT] } =~ s{ (.*?) ( 
+    ${ $s->[text] } =~ s{ (.*?) ( 
         (?:$dTemplate::START_DELIMITER) ( (?:\w|(?:$dTemplate::VAR_PATH_SEP))* ) 
         ( (?:$dTemplate::PRINTF_SEP) (.*?[\w]) )? 
         ( (?:$dTemplate::ENCODER_SEP) (.*?) )?
@@ -157,7 +147,7 @@ sub compile { my $s=shift;
             };
         };
         "";
-    }gxse;
+    }gxsce;
 
     # assigning ID-s for variables
 
@@ -209,26 +199,24 @@ sub compile { my $s=shift;
         }
     }
 
-    $s->[COMPILED] = $compiled;
-    $s->[TEXT]=undef; # free up some memory
+    $s->[compiled] = $compiled;
+    $s->[text]=undef; # free up some memory
 };
 
 sub load_file { my $s=shift;
-    return if $s->[COMPILED] || defined $s->[TEXT] || !defined $s->[FILENAME];
-    if (!open(FILE,$s->[FILENAME])) {
-        warn "Cannot load template file: ".$s->[FILENAME];
-        $s->[TEXT]=\"";
+  return if $s->[compiled] || defined $s->[text] || !defined $s->[filename];
+  if (!open(FILE,$s->[filename])) {
+    warn "Cannot load template file: ".$s->[filename];
+    $s->[text]=\"";
     close (FILE);
     return;
-    };
-    local $/=undef;
-    my $text=<FILE>;
-    $s->[TEXT]=\$text;
-    close (FILE);
+  };
+  local $/=undef;
+  my $text=<FILE>;
+  $s->[text]=\$text;
+  close (FILE);
 };
 
-sub parsehash: lvalue { shift->[PARSEHASH] ||= {} }
-
 package dTemplate::Choose;
 use strict;
 
